summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoTextParag.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoTextParag.h')
-rw-r--r--lib/kotext/KoTextParag.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/kotext/KoTextParag.h b/lib/kotext/KoTextParag.h
index 591242a2..f42c3285 100644
--- a/lib/kotext/KoTextParag.h
+++ b/lib/kotext/KoTextParag.h
@@ -93,7 +93,7 @@ public:
void format( int start = -1, bool doMove = TRUE );
/// Call this to ensure that format() will be called on this paragraph later on
- void tqinvalidate( int chr /*ignored*/ = 0 );
+ void invalidate( int chr /*ignored*/ = 0 );
/// Returns false if format() needs to be called on this paragraph
bool isValid() const;
@@ -132,7 +132,7 @@ public:
void setAlignment( uint a );
void setAlignmentDirect( uint a ) { align = a; }
- uint tqalignment() const;
+ uint alignment() const;
virtual void paint( TQPainter &painter, const TQColorGroup &cg, KoTextCursor *cursor, bool drawSelections,
int clipx, int clipy, int clipw, int cliph ); // kotextparag.cc
@@ -235,9 +235,9 @@ public:
void setLineSpacingType( KoParagLayout::SpacingType _type );
- /** Use this to change the paragraph tqalignment, not KoTextParag::setAlignment ! */
+ /** Use this to change the paragraph alignment, not KoTextParag::setAlignment ! */
void setAlign( int align );
/** Return the real tqalignment: Auto is resolved to either Left or Right */
int resolveAlignment() const;
/// The part of the top margin that can be broken by a page break
@@ -328,7 +328,7 @@ public:
/**
* Load a section of text from a oasis based xml tree.
- * @param parent the xml element that has content as tqchildren.
+ * @param parent the xml element that has content as children.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace
*/
@@ -336,7 +336,7 @@ public:
/**
* Load a section of text from a oasis based xml tree.
- * @param parent the xml element that has content as tqchildren.
+ * @param parent the xml element that has content as children.
* @param context the context
* @param stripLeadingSpace whether to remove leading literal whitespace
* @param hasTrailingSpace whether there was trailing literal whitespace in the span's text
@@ -525,13 +525,13 @@ inline void KoTextParag::setAlignment( uint a )
if ( a == align )
return;
align = a;
- tqinvalidate( 0 );
+ invalidate( 0 );
}
/*inline void KoTextParag::setListStyle( TQStyleSheetItem::ListStyle ls )
{
lstyle = ls;
- tqinvalidate( 0 );
+ invalidate( 0 );
}
inline TQStyleSheetItem::ListStyle KoTextParag::listStyle() const
@@ -235,9 +235,9 @@ public:
void setAlign( int align );
- /** Return the real tqalignment: Auto is resolved to either Left or Right */
+ /** Return the real alignment: Auto is resolved to either Left or Right */
int resolveAlignment() const;
/// The part of the top margin that can be broken by a page break